/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

//Project Include
#include "includes.h"

//Project Variables
Uint16 divider = 0;
#pragma CODE_SECTION(initFlash, "ramfuncs");
extern Uint16 RamfuncsLoadStart, RamfuncsLoadEnd, RamfuncsRunStart;

//handles defined in task.cfg
extern const Semaphore_Handle mySem;

/**
 * Main interrupt routine
 */
void myTickFxn(UArg arg)
{
   PIL_beginInterruptCall();

   if (readInputs())
   {
      // read start/stop button
      if (START_PRESSED && !STOP_PRESSED)
      {
         // Request Normal Operation
         PIL_requestNormalMode();
         //StartControl();

      }
      if (STOP_PRESSED && !START_PRESSED)
      {
         //Request a safe state for a PIL simulation
         PIL_requestReadyMode();
      }
      controlStep();
   }

   /* post the semaphore every second when control system is active */
   divider++;

   if (divider > 10000)
   {
      divider = 0;
      Semaphore_post(mySem);
   }
}

/**
 * Blink the LED when the semaphore is posted
 */
void myTaskFxn(Void)
{
   while (TRUE)
   {
      // pend on semaphore
      Semaphore_pend(mySem, BIOS_WAIT_FOREVER);
      // blink LED
      GpioDataRegs.GPBTOGGLE.bit.GPIO34 = 1;
   }
}

/**
 * Background task - handles communication with client
 */
void BackgroundTaskFxn(Void)
{
   //system synchronous
   PIL_backgroundCall();
}

/**
 * Configures flash memory - needs to be executed from RAM
 */
void initFlash(void)
{
   EALLOW;
   //Enable Flash Pipeline mode to improve performance
   //of code executed from Flash.
   FlashRegs.FOPT.bit.ENPIPE = 1;

   //                CAUTION
   //Minimum waitstates required for the flash operating
   //at a given CPU rate must be characterized by TI.
   //Refer to the datasheet for the latest information.

   //Set the Paged Waitstate for the Flash
   FlashRegs.FBANKWAIT.bit.PAGEWAIT = 3;

   //Set the Random Waitstate for the Flash
   FlashRegs.FBANKWAIT.bit.RANDWAIT = 3;

   //Set the Waitstate for the OTP
   FlashRegs.FOTPWAIT.bit.OTPWAIT = 5;

   //                CAUTION
   //ONLY THE DEFAULT VALUE FOR THESE 2 REGISTERS SHOULD BE USED
   FlashRegs.FSTDBYWAIT.bit.STDBYWAIT = 0x01FF;
   FlashRegs.FACTIVEWAIT.bit.ACTIVEWAIT = 0x01FF;
   EDIS;

   //Force a pipeline flush to ensure that the write to
   //the last register configured occurs before returning.

   asm(" RPT #7 || NOP");
}

/**
 * Helper function to copy code from Flash into RAM
 */
void memCopy(Uint16 *aSourceAddr, Uint16* aSourceEndAddr, Uint16* aDestAddr)
{
   while (aSourceAddr < aSourceEndAddr)
   {
      *aDestAddr++ = *aSourceAddr++;
   }
   return;
}

/**
 * Application entry point
 */
void main()
{
   initGPIO();

   memCopy(&RamfuncsLoadStart, &RamfuncsLoadEnd, &RamfuncsRunStart);

   initFlash();

   initCalibrations();

   //Initialize Communication Interface
   initSCI(ONE_STOPBIT + NO_PARITY + EIGHT_BITS, PIL_D_BaudRate, LSPCLK_HZ);
   writeSCIString("\n\r\n\rStarting PIL Demo Software... ");
   writeSCIString("\n\r");

   //Configure PIL Framework
   PIL_init();
   PIL_setLinkParams(PIL_D_Guid, pollSCI);
   PIL_setCtrlCallback(PilCallback);

   //Initialize Override Probes
   initOverrideProbes();

   //Initialize control system
   initControl();

   //Start in PIL Ready Mode
   PIL_requestReadyMode();

   BIOS_start(); /* does not return */
}
