%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Grid parameters
V_gpeak = 10e3/sqrt(3)*sqrt(2);
V_g2peak = 690/sqrt(3)*sqrt(2);
V_g3peak = 480/sqrt(3)*sqrt(2); 
f_g = 50;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% AC unit transformer
N_t1 = V_gpeak*sqrt(3); % Delta
N_t2 = V_g2peak;
N_t3 = V_g3peak;
R_t1 = 0.4889/2*3; % Delta
L_tk1 = 0.0118/2*3; % Delta
R_t2 = (0.4889/2)/((V_gpeak/V_g2peak)^2);
L_tk2 = (0.0118/2)/((V_gpeak/V_g2peak)^2);
R_t3 = (0.4889/2)/((V_gpeak/V_g3peak)^2);
L_tk3 = (0.0118/2)/((V_gpeak/V_g3peak)^2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 2MW DFIG 
P_n = 2e6; % MW!

n_p = 2;

k_sr = 1/2.6; % Turns ratio s/r

L_ks = 0.12e-3;
L_kr = 0.05e-3;
L_m = 2.9e-3;
gamma = (L_ks + L_m)/L_m;
L_M = gamma*L_m; % Main inductance in stator-flux oriented circuit
L_sigma = gamma*L_ks + (gamma^2)*L_kr; 

R_s = 0.022;
R_r = 0.0018;
R_R = (gamma^2)*R_r; % Rotor resistance in stator-flux oriented circuit

J_g = 75; % kg*(m^2) or N*m*(s^2) of DFIG rotor
J_total_hs = J_g/0.1419*(0.6388 + 0.0114 + 0.0806 + 0.1419); % total inertia of WT on high-speed side

% Limitations
I_R_max = 750*sqrt(2)*(1/k_sr)*(1/gamma);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Machine side converter
% DC-link
C_dc = 53e-3; 
V_dc = 950;
R_brake = 0.13;

% Switching frequency
f_sw = 5e3;

% Flux estimation
w_cutoff = 100;

% Torque control
alpha_c = 100; 
R_mc_a = alpha_c*L_sigma* - R_R - R_s ; % Active damping
K_mc_pd = alpha_c*L_sigma;
K_mc_id = alpha_c*(R_R + R_s + R_mc_a);
K_mc_pq = alpha_c*L_sigma;
K_mc_iq = alpha_c*(R_R + R_s + R_mc_a);

% Speed control
alpha_w = 1;
B_mc_a_w = alpha_w*J_total_hs/n_p;
K_mc_pw = J_total_hs*alpha_w/n_p;
K_mc_iw = B_mc_a_w*alpha_w;
K_mc_b_w = 0.1; % anti-windup

% Reactive power control
alpha_Q = 20;
K_mc_iQ = -alpha_Q/(3 * V_gpeak/N_t1*N_t2*sqrt(3)/2);
K_mc_b_Q = 10; % anti-windup

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Grid side converter
V_g3rms = V_g3peak/sqrt(2);
slip_min = -0.1;
I_g3rms_max = P_n*(-slip_min)/(1-slip_min)/3/V_g3rms;
I_g3peak_max = I_g3rms_max*sqrt(2);
I_g3pp_max = I_g3peak_max*2;

% LCL filter design
THD = 0.04;
I_hfpp_max = 0.2*I_g3peak_max;
L_f1 = V_g3peak/(V_dc/sqrt(3))*cos(pi/6)*(2/3*V_dc - V_g3peak)/(I_hfpp_max*f_sw);
R_f1 = 0;
L_f2 = L_f1*0.15;
C_f = 1/(L_f2*(2*pi*f_sw*10^(20*log10(I_g3pp_max*THD/I_hfpp_max)/40))^2);

% Limitation
I_f_max = 400;

% Current control
alpha_f = 100;
R_res_a = 1e-3; % Active damping resistance for resonance elimitation
R_gc_a = alpha_f*(L_f1 + L_f2) - R_f1;
K_gc_pd = alpha_f*(L_f1 + L_f2);
K_gc_id = alpha_f*(R_f1+R_gc_a);
K_gc_pq = alpha_f*(L_f1 + L_f2);
K_gc_iq = alpha_f*(R_f1+R_gc_a);

% DC-link voltage control
alpha_W = 10;
G_gc_a_W = alpha_W*C_dc/(6 * V_gpeak/N_t1*N_t3*sqrt(3)/2);
K_gc_pW = -alpha_W*C_dc/(6 * V_gpeak/N_t1*N_t3*sqrt(3)/2); % sqrt(3) for delta-y transformer, /2 for rms value
K_gc_iW = -alpha_W*G_gc_a_W;
K_gc_b = 10; % anti-windup

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Mechanical parameters
k_ls_hs = 100/1; % Gearbox ratio low-speed/high-speed


J_gb = J_g/0.1419*0.0806*(k_ls_hs^2);
J_h = J_g/0.1419*0.0114*(k_ls_hs^2);
J_b = J_g/0.1419*(0.6388/3)*(k_ls_hs^2);

k_gbg = 1834.1*(P_n * (n_p^2))/(f_g*2*pi);
k_hgb = 54.75*(P_n * (n_p^2) * (k_ls_hs^2))/(f_g*2*pi);
k_hb = 1259/3*(P_n * (n_p^2) * (k_ls_hs^2))/(f_g*2*pi);

D_g = 0.01*P_n/((f_g*2*pi/n_p)^2);
D_gb = 0.022*(P_n * (k_ls_hs^2))/((f_g*2*pi/n_p)^2);
D_h = 0.01*(P_n * (k_ls_hs^2))/((f_g*2*pi/n_p)^2);
D_b = 0.004/3*(P_n * (k_ls_hs^2))/((f_g*2*pi/n_p)^2);
D_total_hs = D_g + D_gb/(k_ls_hs^2) + D_h/(k_ls_hs^2) + 3*D_b/(k_ls_hs^2);

d_gbg = 10*P_n/((f_g*2*pi/n_p)^2);
d_hgb = 3.5*(P_n * (k_ls_hs^2))/((f_g*2*pi/n_p)^2);
d_hb = 12/3*(P_n * (k_ls_hs^2))/((f_g*2*pi/n_p)^2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Intial conditions
Omega_r_0 = f_g*2*pi/n_p;
Psi_sd_0 = 1e-3;
Psi_sq_0 = 0;% V_gpeak/sqrt(2)*N_t2/N_t1/(2*pi*f_g);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Wind behavior
load('plDFIGTmLookupData.mat');